@@ -823,7 +823,7 @@ class CBinDiff:
                         cur_execute(sql, (bb_ids[key], bb_ids[bb]))
                     except:
                         # key doesnt exist because it doesnt have forward references to any bb
-                        log.error("Error: %s" % str(sys.exc_info()[1]))
+                        log.exception()
 
             # And finally insert the functions to basic blocks relations
             sql = "insert into function_bblocks (function_id, basic_block_id) values (%s, %s)"
@@ -1086,7 +1086,7 @@ class CBinDiff:
                     if percent >= 100:
                         log.info("Callgraphs are absolutely different")
                     else:
-                        log.info("Callgraphs from both programs differ in %f%%" % percent)
+                        log.info("Callgraphs from both programs differ in %f%%", percent)
 
         cur.close()
 
@@ -1165,11 +1165,11 @@ class CBinDiff:
 
             flags = heur["flags"]
             if flags & HEUR_FLAG_UNRELIABLE == HEUR_FLAG_UNRELIABLE and not self.unreliable:
-                log.debug("Skipping unreliable heuristic '%s'" % name)
+                log.debug("Skipping unreliable heuristic '%s'", name)
                 continue
 
             if flags & HEUR_FLAG_SLOW == HEUR_FLAG_SLOW and not self.slow_heuristics:
-                log.debug("Skipping slow heuristic '%s'" % name)
+                log.debug("Skipping slow heuristic '%s'", name)
                 continue
 
             if arg_category == "Unreliable":
@@ -1179,7 +1179,7 @@ class CBinDiff:
                 best = self.best_chooser
                 partial = self.partial_chooser
 
-            log.debug("%s Finding with heuristic '%s'" % (mode, name))
+            log.debug("%s Finding with heuristic '%s'", mode, name)
             sql = sql.replace("$DIFF$", f"`{self.last_diff_db}`")
             sql = sql.replace("$MAIN$", f"`{self.db_name}`")
             sql = sql.replace("$POSTFIX$", postfix)
@@ -1209,16 +1209,16 @@ class CBinDiff:
             while len(threads_list) >= total_cpus:
                 for i, t in enumerate(threads_list):
                     if not t.is_alive():
-                        log.debug("[Parallel] Heuristic '%s' took %f..." % (t.name, time.monotonic() - t.time))
+                        log.debug("[Parallel] Heuristic '%s' took %f...", t.name, time.monotonic() - t.time)
                         del threads_list[i]
-                        log.debug("[Parallel] Waiting for any of %d thread(s) running to finish..." % len(threads_list))
+                        log.debug("[Parallel] Waiting for any of %d thread(s) running to finish...", len(threads_list))
                         break
                     else:
-                        log.info("[Parallel] %d thread(s) running, waiting for at least one to finish..." % len(threads_list), do_log=False)
+                        log.info("[Parallel] %d thread(s) running, waiting for at least one to finish...", len(threads_list))
                         t.join(0.1)
 
         if len(threads_list) > 0:
-            log.info("[Parallel] Waiting for remaining %d thread(s) to finish..." % len(threads_list), do_log=False)
+            log.info("[Parallel] Waiting for remaining %d thread(s) to finish...", len(threads_list))
 
             do_cancel = False
             times = 0
@@ -1227,9 +1227,9 @@ class CBinDiff:
                 for i, t in enumerate(threads_list):
                     t.join(0.1)
                     if not t.is_alive():
-                        log.debug("[Parallel] Heuristic '%s' took %f..." % (t.name, time.monotonic() - t.time))
+                        log.debug("[Parallel] Heuristic '%s' took %f...", t.name, time.monotonic() - t.time)
                         del threads_list[i]
-                        log.debug("[Parallel] Waiting for remaining %d thread(s) to finish..." % len(threads_list))
+                        log.debug("[Parallel] Waiting for remaining %d thread(s) to finish...", len(threads_list))
                         break
 
                     t.join(0.1)
@@ -1248,7 +1248,7 @@ class CBinDiff:
                     names = []
                     for x in threads_list:
                         names.append(x.name)
-                    log.info("[Parallel] %d thread(s) still running:\n\n%s" % (len(threads_list), ", ".join(names)))
+                    log.info("[Parallel] %d thread(s) still running:\n\n%s", len(threads_list), ", ".join(names))
 
     def ast_ratio(self, ast1, ast2):
         if not self.relaxed_ratio:
@@ -1348,7 +1348,7 @@ class CBinDiff:
 
             i += 1
             if i % 50000 == 0:
-                log.info("Processed %d rows..." % i)
+                log.info("Processed %d rows...", i)
             row = cur.fetchone()
             if row is None:
                 break
@@ -1425,7 +1425,7 @@ class CBinDiff:
 
             i += 1
             if i % 50000 == 0:
-                log.info("Processed %d rows..." % i)
+                log.info("Processed %d rows...", i)
             row = cur.fetchone()
             if row is None:
                 break
@@ -1490,7 +1490,7 @@ class CBinDiff:
 
             i += 1
             if i % 50000 == 0:
-                log.info("Processed %d rows..." % i)
+                log.info("Processed %d rows...", i)
 
             row = cur.fetchone()
             if row is None:
@@ -1568,7 +1568,7 @@ class CBinDiff:
         while 1:
             i += 1
             if i % 1000 == 0:
-                log.info("Processed %d rows..." % i)
+                log.info("Processed %d rows...", i)
             row = cur.fetchone()
             if row is None:
                 break
@@ -1694,7 +1694,7 @@ class CBinDiff:
                                 and f.name not like 'nullsub_%'"""
         
         desc = "Perfect match, same name"
-        log.info("Finding with heuristic '%s'" % desc)
+        log.info("Finding with heuristic '%s'", desc)
         cur.execute(sql)
         rows = cur.fetchall()
         cur.close()
@@ -1943,7 +1943,7 @@ class CBinDiff:
         while len(the_items) > 0:
             total_dones += 1
             if total_dones % 1000 == 0:
-                log.info("Processed %d callgraph matches..." % total_dones)
+                log.info("Processed %d callgraph matches...", total_dones)
 
                 curr_best_matches = len(self.best_chooser.items)
                 curr_part_matches = len(self.partial_chooser.items)
@@ -2183,7 +2183,7 @@ class CBinDiff:
                 l.insert(0, 'secondary')
                 cur.execute(unmatched_sql, l)
 
-            log.info("Diffing results saved in DB '%s'." % filename)
+            log.info("Diffing results saved in DB '%s'.", filename)
         finally:
             results_db.commit()
             cur.close()
@@ -2211,11 +2211,11 @@ class CBinDiff:
             return False
 
         if row["value"] != VERSION_VALUE:
-            log.warning("WARNING: The database is from a different version (current %s, database %s)!" % (VERSION_VALUE, row[0]))
+            log.warning("WARNING: The database is from a different version (current %s, database %s)!", VERSION_VALUE, row[0])
 
         try:
             t0 = time.monotonic()
-            log.debug("Diffing...", True)
+            log.debug("Diffing...")
 
             self.do_continue = True
             if self.equal_db():
